@@ -10,7 +10,7 @@ import tqdm
 from typing import List
 import requests_toolbelt
 
-__version__ = "1.0.7"
+__version__ = "1.0.8"
 package_name = "anon"
 url = 'https://api.anonfiles.com/upload'
 
@@ -89,6 +89,9 @@ def upload(filenames:List[str]):
             urlshort = resp['data']['file']['url']['short']
             urllong = resp['data']['file']['url']['full']
             print(f'[SUCCESS]: Your file has been succesfully uploaded:\nFull URL: {urllong}\nShort URL: {urlshort}')
+            with open('urls.txt', 'a+') as f:
+                f.write(urllong)
+            print('url saved in urls.txt file')
         else:
             message = resp['error']['message']
             errtype = resp['error']['type']
